# Summary

[Introduction](./introduction.md)

# Preliminaries

- [Architecture](./architecture.md)
- [Source code, Building, and Installation](./install.md)
- [Glossary](./glossary.md)

# User and Administration Guide

- [System overview](./operation/index.md)
- [The System Bus: syndicate-server](./operation/system-bus.md)
  - [Configuration language](./operation/scripting.md)
  - [Services and service dependencies](./operation/service.md)
  - [Built-in services and service classes](./operation/builtin/index.md)
    - [Gatekeeper](./operation/builtin/gatekeeper.md)
    - [Logging](./operation/builtin/logging.md)
    - [TCP/IP, WebSocket and Unix-socket Transports](./operation/builtin/relay-listener.md)
    - [Configuration watcher](./operation/builtin/config-watcher.md)
    - [Daemons and external programs](./operation/builtin/daemon.md)
- [Configuration files and directories](./operation/synit-config.md)
- [How-to ...](./operation/howto/index.md)
  - [Define services and service classes](./operation/howto/define-services.md)
  - [Restart services](./operation/howto/restart-services.md)
  - [Schedule one-off or repeating tasks](./operation/howto/schedule-tasks.md)
  - [Manage user settings](./operation/howto/manage-user-settings.md)
  - [Reboot and power off the machine](./operation/howto/reboot-and-power-off.md)
  - [Suspend the machine](./operation/howto/suspend.md)

# Tools

- [The `preserves-tools` package](./tools/preserves-tools.md)

# Programming Guide and Reference

- [Preserves](./guide/preserves.md)
- [Working with schemas](./guide/working-with-schemas.md)
- [Capturing and rendering interaction traces](./guide/tracing.md)

# Programming Libraries

- [Python support libraries](./libraries/python-support.md)
- [Shell-scripting libraries](./libraries/shell-scripting.md)

# Protocols and Schema Definitions

- [Preserves schemas]()
  - [Preserves Schema metaschema]()
  - [Preserves Path schema]()
- [Syndicated Actor Model schemas]()
  - ["Observe" assertions]()
  - [Patterns over assertions]()
  - [Gatekeeper and Sturdy-references]()
  - [Wire-protocol]()
  - [Service dependencies]()
  - [Tracing]()
  - [Transport addresses]()
- [Synit schemas]()
  - [Audio control]()
  - [Telephony (call and SMS) support]()
  - [Modem support]()
    - [Hayes]()
    - [Samsung Galaxy S7]()
  - [MIME type support]()
  - [Network core status and configuration]()
  - [Sound effects]()
  - [Time stamps]()
  - [User interface definitions and interaction]()
  - [User settings]()

# Specifications and Theory

- [Syndicated Actor Model](./syndicated-actor-model.md)
- [Protocol specification](./protocol.md)
- [System layer analysis]()
